/* valaccodestatement.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <ccode/valaccodestatement.h>




enum  {
	VALA_CCODE_STATEMENT_DUMMY_PROPERTY
};
static gpointer vala_ccode_statement_parent_class = NULL;



/**
 * Represents a statement in the C code.
 */
ValaCCodeStatement* vala_ccode_statement_new (void) {
	ValaCCodeStatement * self;
	self = g_object_newv (VALA_TYPE_CCODE_STATEMENT, 0, NULL);
	return self;
}


static void vala_ccode_statement_class_init (ValaCCodeStatementClass * klass) {
	vala_ccode_statement_parent_class = g_type_class_peek_parent (klass);
}


static void vala_ccode_statement_init (ValaCCodeStatement * self) {
}


GType vala_ccode_statement_get_type (void) {
	static GType vala_ccode_statement_type_id = 0;
	if (G_UNLIKELY (vala_ccode_statement_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeStatement), 0, (GInstanceInitFunc) vala_ccode_statement_init };
		vala_ccode_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeStatement", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
	}
	return vala_ccode_statement_type_id;
}




